@@ -11,11 +11,13 @@ descriptive_data <- function(
 ) {
   .cat_counter(data, {{ x }}, {{ y }}) %>%
     mutate(
-      .label = case_when(
-        grepl("perc|prop", label.content) ~ paste0(round(perc, digits.perc), "%"),
-        grepl("count|n|N", label.content) ~ .prettyNum(counts),
-        .default = paste0(.prettyNum(counts), "\n", "(", round(perc, digits.perc), "%)")
-      ), # reorder the category factor levels to order the legend
+      .label = if (grepl("perc|prop", label.content)) {
+        paste0(round(perc, digits.perc), "%")
+      } else if (grepl("count|n|N", label.content)) {
+        .prettyNum(counts)
+      } else {
+        paste0(.prettyNum(counts), "\n", "(", round(perc, digits.perc), "%)")
+      }, # reorder the category factor levels to order the legend
       {{ x }} := factor({{ x }}, unique({{ x }}))
     )
 }
